;This file is copyright (c) 1990 Informant Communications Group and the
;article author. The material here may be used in an application provided
;that this copyright/disclaimer information is kept in the original source 
;file. The material presented here is provided "as is" and with no guarantee.
;Informant Communications Group/Paradox Informant assume no responsibility
;for the use or misuse of the material contained within. 
;
;Contents        : procedure AutoWait
;Source File     : AUTOWAIT.SC
;Author          : Michael R. Baum
;Informant Issue : October 1991
;Description     : A utility for use with DoWait from the Paradox Data Entry
;                  toolkit that simplifies and manages the IMAGENO() function
;                  for embedded forms in Paradox tables. The AutoWait
;                  procedure is called from an application with the following
;                  syntax:
;                  
;                  Autowait(Mtable,Mform)
;
;                  where Mtable is the master table of the form to be edited
;                  and Mform is the form of Mtable to be edited
;
; Paradox Informant
; 8525 Elk Grove Blvd.
; Suite 126
; Elk Grove, CA  95624-1777
; Phone: (916) 686-6610
; Fax  : (916) 686-8497
; BBS  : (916) 686-4740
;


PROC autowait(table_name,form_name)

   PRIVATE sys_sname,aw_image,aw_imageno,aw_images,aw_image_str,
           aw_table_str,icount
   sys_sname = "autowait"

   IF NOT TABLERIGHTS(table_name,"ReadOnly")         ; check for table
     THEN MESSAGE "Access to " + table_name + " Data Base Denied..."
          BEEP
          SLEEP 3000
          RETURN false                               ; return IF none
   ENDIF

   MESSAGE "Opening " + table_name + " Data Bases ..." 	; inform operator

   VIEW table_name				     ; Open Table
   curr_form = form_name			     ; Setup Form

   WHILE curr_form <> ""                             ; Check for empty table

      IF NIMAGERECORDS() = 0
        THEN COEDITKEY
             IF NOT retval
               THEN MESSAGE table_name + " Data Base Empty"
                    BEEP			     ; otherwise
                    SLEEP 3000                       ; deny access
                    curr_form = ""                   ; no form available
                    LOOP
             ENDIF
      ENDIF

      PICKFORM curr_form

      sys_mode     = sysmode()		; initialize mode variable
      aw_image     = imageno()		; get current image number for table
      aw_imageno   = nimages()		; get total number of images
      aw_imageS    = aw_imageno - aw_image + 1	; Number of DOWAIT images
      aw_image_str = ""
      aw_table_str = ""

      FOR icount FROM aw_image TO aw_imageS	     ; Set up dowait strings
          aw_image_str = aw_image_str + strval(icount) + ","
          MOVETO icount
          aw_table_str = aw_table_str + table() + ","
      ENDFOR

      aw_image_str = SUBSTR(aw_image_str,1,LEN(aw_image_str)-1)
                                                     ; removes trailing comma
      aw_table_str = SUBSTR(aw_table_str,1,LEN(aw_table_str)-1)
                                                     ; removes trailing comma

      MOVETO table_name
      IF NOT ISFORMVIEW()                            ; IF routine came out of form mode
        THEN PICKFORM curr_form                      ; during image scan, return to
      ENDIF                                          ; form mode
      CTRLHOME                                       ; go to top of table

      IF ISRUNTIME()                                 ; check runtime status
        THEN tklibname = "runtool"                   ; and assign library name
      ENDIF

      InitWait(aw_imageS,aw_image_str,aw_table_str)
      RELEASE PROCS initwait

      dowait("")				     ; Process the table
      RELEASE PROCS dowait

   ENDWHILE

   MESSAGE "Closing " + table_name + " Data Bases..." 	; inform operator
   MOVETO table_name
   CLEARIMAGE
   PROMPT                                               ; clear prompts
   RETURN true

ENDPROC
